@@ -8,5 +8,5 @@ __version__ = "0.4.0"
 
 
 def xls2html(*args, **kwargs):
-    warnings.warn("This func was renamed to xlsx2html.", DeprecationWarning)
+    warnings.warn("This func was renamed toadactivexlsx2html.", DeprecationWarning)
     return xlsx2html(*args, **kwargs)
