@@ -12,10 +12,10 @@ from openpyxl.styles.colors import COLOR_INDEX, aRGB_REGEX
 from openpyxl.utils import rows_from_range, column_index_from_string, units
 from openpyxl.worksheet.worksheet import Worksheet
 
-from xlsx2html.compat import OPENPYXL_24
-from xlsx2html.constants.border import DEFAULT_BORDER_STYLE, BORDER_STYLES
-from xlsx2html.format import format_cell
-from xlsx2html.utils.image import bytes_to_datauri
+from adactivexlsx2html.compat import OPENPYXL_24
+from adactivexlsx2html.constants.border import DEFAULT_BORDER_STYLE, BORDER_STYLES
+from adactivexlsx2html.format import format_cell
+from adactivexlsx2html.utils.image import bytes_to_datauri
 
 
 def render_attrs(attrs):
@@ -254,7 +254,7 @@ def worksheet_to_data(ws, locale=None, fs=None, default_cell_border="none"):
 
 
 def render_table(data, append_headers, append_lineno):
-    length = 18
+    length = 20
     n = math.ceil(len(data["rows"]) / length)
     html = []
     for index in range(0, n):
