@@ -2,7 +2,7 @@ import re
 
 from babel import Locale, UnknownLocaleError
 
-from xlsx2html.constants import LCID_HEX_MAP
+from adactivexlsx2html.constants import LCID_HEX_MAP
 
 LOCALE_FORMAT_RE = re.compile(
     r"""
